SmartCheckoutCallbacks class

Constructors

SmartCheckoutCallbacks({dynamic onSuccess(Map<String, dynamic> result)?, dynamic onError(Map<String, dynamic> error)?, VoidCallback? onClose})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onClose VoidCallback?
final
onError → dynamic Function(Map<String, dynamic> error)?
final
onSuccess → dynamic Function(Map<String, dynamic> result)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited