SmartCheckoutConfig class
Constructors
- SmartCheckoutConfig({required SmartCheckoutEnvironment environment, String? sessionCode, String? partnerKey, Uri? deepLink, double? initialHeightFraction, SmartCheckoutStyle? style})
-
const
- SmartCheckoutConfig.from(Map map)
-
factory
Properties
- deepLink → Uri?
-
final
- environment → SmartCheckoutEnvironment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialHeightFraction → double
-
final
- partnerKey → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionCode → String?
-
final
- style → SmartCheckoutStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited